@@ -15,7 +15,7 @@ except:
 # In[3]:
 
 
-version = '0.55'
+version = '0.56'
 
 import re
 import tempfile
@@ -925,17 +925,22 @@ def jnImgToHtmlB64(img):
 
 #def jnHtmlImgsRow(imgs, names=None):
 
-def jnImageRow(imgs, names=None, width=100, external=False):
+def jnImageRow(imgs, names=None, width=100, external=False, title_img=None, title=None):
     _row = lambda x: '<tr>' + x + '</tr>'
     _col = lambda x: '<td style="text-align:center">' + x + '</td>'
-    _cols = lambda x: "".join(map(_col, x))
+    _nacols = lambda x: prefix_name + "".join(map(_col, x))
+    
+    prefix_name = "" if title is None else _col(title)
+    prefix_img = "" if title is None else _col("")
+
     if external:
-        _imcols = lambda x: "".join(map(_col, map(lambda y: '<img src="{}" style="display:block; margin:0 auto;">'.format(y), x)))
+        _imcols = lambda x: prefix_img + "".join(map(_col, map(lambda y: '<img src="{}" style="display:block; margin:0 auto;">'.format(y), x)))
     else:
-        _imcols = lambda x: "".join(map(_col, map(jnImgToHtmlB64, x)))
+        _imcols = lambda x: prefix_img + "".join(map(_col, map(jnImgToHtmlB64, x)))
+        
     _tab = lambda x: '<table width="{width}%">'.format(width=width) + x + '</table>'
     
-    header = "" if names is None else _row(_cols(names))
+    header = "" if names is None else _row(_nacols(names))
     html = _tab(header + _row(_imcols(imgs)))
     display(HTML(html))
 
@@ -952,7 +957,7 @@ if is_testing():
 
 
 if is_testing():
-    jnImageRow(imgs=["http://via.placeholder.com/40x20.png", "http://via.placeholder.com/40x20.png"], names=["a", "b"], external=True)
+    jnImageRow(imgs=["http://via.placeholder.com/40x20.png", "http://via.placeholder.com/40x20.png"], names=["a", "b"], external=True, title='test')
 
 
 # In[82]:
@@ -1135,7 +1140,7 @@ if is_testing():
     package_files['README.md'] = ""
 
 
-# In[ ]:
+# In[96]:
 
 
 if is_testing():
@@ -1144,7 +1149,7 @@ if is_testing():
     
 
 
-# In[ ]:
+# In[97]:
 
 
 if is_testing():
@@ -1155,7 +1160,7 @@ lx/__init__.py
 """
 
 
-# In[ ]:
+# In[98]:
 
 
 if is_testing():
